@@ -4,7 +4,7 @@ Main interface for proton service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_proton import (
         Client,
         EnvironmentDeployedWaiter,
@@ -27,10 +27,8 @@ Usage::
         ServiceUpdatedWaiter,
     )
 
-    session = boto3.Session()
-
-    client: ProtonClient = boto3.client("proton")
-    session_client: ProtonClient = session.client("proton")
+    session = Session()
+    client: ProtonClient = session.client("proton")
 
     environment_deployed_waiter: EnvironmentDeployedWaiter = client.get_waiter("environment_deployed")
     environment_template_version_registered_waiter: EnvironmentTemplateVersionRegisteredWaiter = client.get_waiter("environment_template_version_registered")
