@@ -1,7 +1,7 @@
 """
 Type annotations for proton service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_proton/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_proton/literals/)
 
 Usage::
 
@@ -44,7 +44,9 @@ __all__ = (
     "ServiceTemplateVersionRegisteredWaiterName",
     "ServiceUpdatedWaiterName",
     "TemplateVersionStatusType",
+    "ProtonServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -102,6 +104,7 @@ ServiceUpdatedWaiterName = Literal["service_updated"]
 TemplateVersionStatusType = Literal[
     "DRAFT", "PUBLISHED", "REGISTRATION_FAILED", "REGISTRATION_IN_PROGRESS"
 ]
+ProtonServiceName = Literal["proton"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -135,6 +138,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -389,6 +393,18 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_environment_account_connections",
     "list_environment_template_versions",
